<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Hypochondria
 */

if ( ! function_exists( 'hypochondria_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @return void
 */
function hypochondria_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'hypochondria' ); ?></h1>
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
				<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'hypochondria' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
				<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'hypochondria' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'hypochondria_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 *
 * @return void
 */
function hypochondria_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation post-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'hypochondria' ); ?></h1>
		<div class="nav-links">
			<?php
				previous_post_link( '<div class="nav-previous">%link</div>', _x( '<span class="meta-nav">&larr;</span> %title', 'Previous post link', 'hypochondria' ) );
				next_post_link(     '<div class="nav-next">%link</div>',     _x( '%title <span class="meta-nav">&rarr;</span>', 'Next post link',     'hypochondria' ) );
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'hypochondria_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 */
function hypochondria_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	global $post;
	
	if ( 'pingback' == $comment->comment_type || 'trackback' == $comment->comment_type ) : ?>
		<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
			<article class="comment-body">
				<header class="comment-meta">
					<cite><?php _e( 'Pingback:', 'hypochondria' ); ?></cite>
				
					<?php edit_comment_link( __( 'Edit', 'hypochondria' ) ); ?>
				</header>
				
				<section class="pingback-content">
					<?php comment_author_link(); ?>
				</section>
			</article><!-- .comment-body -->
		</li><!-- #comment-id -->
	<?php else : ?>
		<li id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
			<article class="comment-body">
				<header class="comment-meta">
					<?php
					$author = get_comment_author_link();
					if ( $comment->user_id == $post->post_author ) :
						$bypostauthor = sprintf( ' (%s)', __( 'Post Author', 'hypochondria' ) );
					else :
						$bypostauthor = '';
					endif;
					
					printf( '<cite class="fn">%1$s%2$s</cite>',
						$author, // %1$s
						$bypostauthor // %2$s
					);
					?>
		
					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
					        <time datetime="<?php comment_time( 'c' ); ?>">
					        	<?php printf( _x( '%1$s at %2$s', '1: Date, 2: Time', 'hypochondria' ),
					        		get_comment_date(), // %1$s
					        		get_comment_time() // %2$s
					        	);
					        	?>
					        </time>
					</a>
				</header><!-- .comment-meta -->
				
				<div class="comment-wrap">
					<section class="comment-avatar">
						<?php
						if ( 0 != $args['avatar_size'] ) :
							echo get_avatar( $comment, $args['avatar_size'] );
						endif;
						?>
					</section><!-- .comment-avatar -->
					
					<section class="comment-content">
						<?php
						if ( '0' == $comment->comment_approved ) : ?>
							<p><?php _e( 'Your comment is awaiting moderation.', 'hypochondria' ); ?></p>
						<?php endif; ?>
						
						<p><?php comment_text(); ?></p>
					</section><!-- .comment-content -->
				</div><!-- .comment-wrap -->
		
				<footer class="comment-actions">
					<?php
					comment_reply_link( array_merge( $args, array(
					        'add_below' => 'div-comment',
					        'depth'     => $depth,
					        'max_depth' => $args['max_depth']
					) ) );
					
					edit_comment_link( __( 'Edit', 'hypochondria' ) ); ?>					
				</footer>
			</article><!-- .comment-body -->
		</li><!-- #comment-id -->
	<?php
	endif;
}
endif; // ends check for hypochondria_comment()

if ( ! function_exists( 'hypochondria_footer_meta' ) ) :
/**
 * Displays post meta information
 */
function hypochondria_footer_meta() {
	global $post; ?>
	
	<ul>
		<?php if ( is_attachment() ) : ?>
			<li class="meta-attach">
				<?php
				printf( __( '<a href="%1$s">%2$s</a>', 'pixilate' ),
					esc_url( get_permalink( $post->post_parent ) ), // %1$s
					esc_html( get_the_title( $post->post_parent ) )// %2$s
				);
				?>
			</li>
			
			<li class="meta-zoom">
				<?php
				if ( wp_attachment_is_image() && 'attachment' == $post->post_type ) :
					$attachment_metadata = wp_get_attachment_metadata( $post->ID );
					printf ( __( '<a href="%1$s">%2$s by %3$s</a>', 'pixilate' ),
						esc_url( wp_get_attachment_url( $post->ID ) ),
						$attachment_metadata[ 'height' ],
						$attachment_metadata[ 'width' ]
					);
				endif;
				?>
			</li>
			
		<?php elseif ( is_single() || is_home() || is_archive() || is_search() ) : ?>
			<li class="meta-category">
				<?php
				/* translators: used between list items, there is a space after the comma */
				$categories = get_the_category_list( __( ', ', 'hypochondria' ) );
				if ( $categories ) : ?>
					<span><?php echo $categories; ?></span>
				<?php else : ?>
					<span><?php printf( __( 'Uncategorized', 'hypochondria' ) ); ?></span>
				<?php endif; ?>
			</li>
			
			<li class="meta-tag">
				<?php
				/* translators: used between list items, there is a space after the comma */
				$tags = get_the_tag_list( '', __( ', ', 'hypochondria' ) );
				if ( $tags ) : ?>
					<span><?php echo $tags; ?></span>
				<?php else : ?>
					<span><?php printf( __( 'Untagged', 'hypochondria' ) ); ?></span>
				<?php endif; ?>
			</li>
		<?php endif;
		
		if ( ! is_page() ) : ?>
			<li class="meta-date">
				<?php
				$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
				if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
				        $time_string .= '<time class="updated" datetime="%3$s">%4$s</time>';
				}
				
				$time_string = sprintf( $time_string,
				        esc_attr( get_the_date( 'c' ) ),
				        esc_html( get_the_date() ),
				        esc_attr( get_the_modified_date( 'c' ) ),
				        esc_html( get_the_modified_date() )
				);
				printf( '<a href="%1$s" rel="bookmark">%2$s</a>',
					esc_url( get_permalink() ), // %1$s
					$time_string // %2$s
				);
				?>
			</li>
			
			<li class="meta-author">
				<?php
				printf( '<a class="url fn n" href="%1$s">%2$s</a>',
					esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
					esc_html( get_the_author() )
				);
				?>
			</li>
		
			<li class="meta-comment">
				<?php
				if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) :
					comments_popup_link( __( 'Leave a comment', 'hypochondria' ), __( '1 Comment', 'hypochondria' ), __( '% Comments', 'hypochondria' ) );
				else : 
					printf( __( 'Comments are closed', 'hypochondria' ) );
				endif;
				?>
			</li>
		<?php endif;
		
		$edit = get_edit_post_link();
		if ( $edit ) : ?>
			<li class="meta-edit">
				<?php edit_post_link( __( 'Edit', 'hypochondria' ) ); ?>
			</li>
		<?php endif; ?>
	</ul>
<?php }
endif; // ends check for hypochondria_footer_meta()

/**
 * Returns true if a blog has more than 1 category.
 */
function hypochondria_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'all_the_cool_cats' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'hide_empty' => 1,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'all_the_cool_cats', $all_the_cool_cats );
	}

	if ( '1' != $all_the_cool_cats ) {
		// This blog has more than 1 category so hypochondria_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so hypochondria_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in hypochondria_categorized_blog.
 */
function hypochondria_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'all_the_cool_cats' );
}
add_action( 'edit_category', 'hypochondria_category_transient_flusher' );
add_action( 'save_post',     'hypochondria_category_transient_flusher' );